Method: TelegramBot::MaskPosition#x_shift
- Defined in:
- lib/telegram-bot/models/mask_position.rb
#x_shift ⇒ Object
Shift by X-axis measured in widths of the mask scaled to the face size, from left to right. For example, choosing -1.0 will place mask just to the left of the default mask position.
23 24 25 |
# File 'lib/telegram-bot/models/mask_position.rb', line 23 def x_shift @x_shift end |